@@ -1,6 +1,6 @@
 #include "clientsocket.ih"
 
-int ClientSocket::connect() throw (Errno)
+int ClientSocket::connect()
 {
     if (::connect(socket(), sockaddrPtr(), size()) < 0)
         throw Errno("ClientSocket::connect()");
