@@ -1,5 +1,5 @@
-#ifndef _INCLUDED_DRIVER_H_
-#define _INCLUDED_DRIVER_H_
+#ifndef INCLUDED_DRIVER_H_
+#define INCLUDED_DRIVER_H_
 
 #include <iostream>
 #include <string>
