@@ -2,7 +2,7 @@
 
 DateTime &DateTime::operator-=(tm const &fields)
 {
-    tm work = fields;
+    struct tm work = fields;
     d_time -= mktime(&work);
     breakDown(d_type);
     return *this;
