@@ -8,7 +8,7 @@ int MultiStreambuf::sync()
     Insert istruct = {d_buffer, true};
 
     for_each(d_os.begin(), d_os.end(), 
-             Wrap1c<stream, Insert>(&insert, istruct));
+             FnWrap1c<stream &, Insert &>(&insert, istruct));
 
     d_buffer.erase();
     return istruct.ok ? 0 : 1;
